@@ -11,7 +11,7 @@
 
 package Config::Model::TkUI ;
 {
-  $Config::Model::TkUI::VERSION = '1.336';
+  $Config::Model::TkUI::VERSION = '1.338';
 }
 
 use 5.10.1 ;
@@ -183,6 +183,14 @@ sub Populate {
     $loc_frame->Label(-text => 'location :') -> pack ( -side => 'left');
     $loc_frame->Label(-textvariable => \$cw->{location}) -> pack ( -side => 'left');
 
+    # create 'show only custom values'
+    $cw->{show_only_custom} = 0;
+    $loc_frame->Checkbutton(
+        -variable => \$cw->{show_only_custom},
+        -command => sub {$cw->reload} ,
+    ) -> pack (-side => 'right') ;
+    $loc_frame->Label(-text => 'show only custom values') ->pack(-side => 'right') ;
+
     # add bottom frame
     my $bottom_frame = $cw->Frame
       ->pack  (qw/-pady 0 -fill both -expand 1/ ) ;
@@ -827,10 +835,11 @@ sub disp_leaf {
     my $value = $leaf_object->fetch(check => 'no', silent => 1) ;
     my $tkt = $cw->{tktree} ;
 
-    my $img ;
+    my ($is_customised, $img) ;
     {
 	no warnings qw/uninitialized/ ;
-	$img = $cust_img if (defined $value and $std_v ne $value) ;
+        $is_customised = ! ( $std_v eq $value)  ;
+	$img = $cust_img if $is_customised ;
 	$img = $warn_img if $leaf_object->warning_msg ;
 	$img = $error_img if $leaf_object->error_msg;
     }
@@ -849,6 +858,9 @@ sub disp_leaf {
     $tkt->itemCreate($path,2, -text => $cw->trim_value($value)) ;
 
     $tkt->itemCreate($path,3, -text => $cw->trim_value($std_v)) ;
+    
+    my $meth = ($cw->{show_only_custom} and not $is_customised) ? 'hide' : 'show' ;
+    $tkt->$meth(entry => $path) ; 
 }
 
 sub disp_node {
@@ -1080,6 +1092,13 @@ sub setup_wizard {
       ) ;
 }
 
+# FIXME: need to be able to search different types.
+# 2 choices
+# - destroy and re-create the searcher when it's modified
+# - change the searcher (TreeSearcher) to accept type modif
+# For the latter: it would be better to accept a set of types instead of
+# all or just one type (to implement a set of check buttons)
+
 sub create_find_widget {
     my $cw = shift ;
     my $f = $cw -> Frame(-relief => 'ridge', -borderwidth => 1 , ) ;
@@ -1116,6 +1135,12 @@ sub create_find_widget {
         ) -> pack(-side => 'left');
     }
     
+    # bind Return (or Enter) key 
+    $e->bind( 
+        '<Key-Return>',
+        sub { $cw -> find_item('next', $searcher,\$search, \@result) ;}
+    ) ;
+    
     return $f ;
 }
 
